@@ -277,9 +277,10 @@ class EditsManager(object):
         return edit_fact
 
     def apply_edits(self, *edit_facts):
-        # Called on paste, edit-time, and after carousel prompts user for edits.
-        # Note that edit_time_adjust has 3 facts (curr, prev, next) and 1 of the
-        #   latter times may be None. Extract that None entry here.
+        # Called on edit-time, and after carousel prompts user for edits.
+        # edit_facts is a list of 1 or 2 Facts: the edited Fact, and then
+        # maybe a prev or next Fact, if one exists and was affected by a
+        # change to the edited Fact's start or end time.
         edit_facts = list(filter(None, edit_facts))
         applied_edits = self.update_redo_undo_and_conjoined(edit_facts)
         if not applied_edits:
@@ -294,17 +295,18 @@ class EditsManager(object):
         self.redo_undo.add_undoable(was_facts, what)
 
     def update_redo_undo_and_conjoined(self, edit_facts):
+        # edit_facts is 1 or 2 items: current fact, maybe followed by neighbor.
         last_edits = self.redo_undo.remove_undo_if_nothing_changed(edit_facts)
         if last_edits is None:
             return False
 
         for idx, edit_fact in enumerate(edit_facts):
-            # 2018-08-04 12:29: EXPLAIN: idx == 0 ?? Why?
-            #  Oh, only unmark interval-gap if it's first fact in edit_facts,
-            #  which indicates user deliberately edited gap-fact; as opposed
-            #  to if gap-fact is later in edit_facts, and then it was edited
-            #  by time adjust of another fact. Feels like could be better way.
-            self.manage_edited_dirty_deleted(edit_fact, undelete=(idx == 0))
+            # Only unmark interval-gap if this is the first fact in edit_facts,
+            # which indicates user deliberately edited gap-fact; as opposed
+            # to if gap-fact is later in edit_facts, and then it was edited
+            # by time adjust of another fact. Feels like could be better way.
+            is_oldest_fact = idx == 0
+            self.manage_edited_dirty_deleted(edit_fact, undelete=is_oldest_fact)
             self.manage_edited_edit_facts(edit_fact)
 
         self.conjoined.apply_edits(edit_facts, last_edits)
@@ -387,6 +389,10 @@ class EditsManager(object):
 
     # ***
 
+    def toss_last_edit(self):
+        undone = self.redo_undo.undo_last_edit(restore_facts=None)
+        return undone
+
     def undo_last_edit(self):
         undone = self.redo_undo.undo_last_edit(self.restore_facts)
         return undone
