@@ -662,13 +662,36 @@ class ZoneDetails(
             was_fact = edit_fact.copy()
             if self.active_widgets is self.widgets_start:
                 was_time = edit_fact.start_fmt_local
-                applied = self.apply_edit_time_start(edit_fact, edit_time)
+                applied = self.apply_edit_time_start(
+                    edit_fact, edit_time, verify_fact_times,
+                )
             else:
                 self.affirm(self.active_widgets is self.widgets_end)
                 was_time = edit_fact.end_fmt_local_or_now
-                applied = self.apply_edit_time_end(edit_fact, edit_time)
+                applied = self.apply_edit_time_end(
+                    edit_fact, edit_time, verify_fact_times,
+                )
             check_conflicts_and_confirm(edit_fact, was_fact, was_time, applied)
 
+        def verify_fact_times(edit_fact):
+            # Check that edit_fact.start < edit_fact.end now, rather than
+            # via apply_edit_time_start/apply_edit_time_end's call to
+            # edits_manager.apply_edits. By doing it now, we will not have
+            # to cleanup the undo stack, nor fix the current fact, nor any
+            # neighbor fact.
+            conflicts = must_complete_times(
+                self.carousel.controller,
+                new_facts=[edit_fact],
+                progress=None,
+                leave_blanks=True,
+                other_edits={},
+                suppress_barf=True,
+            )
+            if conflicts:
+                edited_fact_alert_conflicts(conflicts)
+                return False
+            return True
+
         def check_conflicts_and_confirm(edit_fact, was_fact, was_time, applied):
             if not applied:
                 # Nothing changed; no-op.
@@ -683,18 +706,36 @@ class ZoneDetails(
             #   to come before the start.
             conflicts = edited_fact_conflicts(edit_fact)
             if conflicts:
-                self.affirm(len(conflicts) == 1)
-                conflict_msg = conflicts[0][2]
-                show_message_conflicts_found(conflict_msg)
-                # Reset the Fact, otherwise the edit will stick!
-                # Ha! Note that we already did the deed, so go through undo-redo!
-                #   # Won't work! Screws up prev/next links, and leaves undo!:
-                #   edit_fact.end = was_fact.end
-                #   edit_fact.start = was_fact.start
-                undone = self.carousel.edits_manager.undo_last_edit()
-                self.affirm(undone)
-                # Update the control text.
-                self.active_widgets.text_area.text = was_time
+                edited_fact_alert_conflicts(conflicts)
+                edited_fact_cleanup_rejected(edit_fact, was_fact, was_time)
+
+        def edited_fact_alert_conflicts(conflicts):
+            self.affirm(len(conflicts) == 1)
+            conflict_msg = conflicts[0][2]
+            show_message_conflicts_found(conflict_msg)
+
+        def edited_fact_cleanup_rejected(edit_fact, was_fact, was_time):
+            # Toss the rejected edit from the undo stack.
+            undone = self.carousel.edits_manager.toss_last_edit()
+            self.affirm(undone)
+            # Reset the Fact, otherwise the edit will stick!
+            #   # Won't work! Screws up prev/next links, and leaves undo!:
+            #   edit_fact.start = was_fact.start
+            #   edit_fact.end = was_fact.end
+            # MAYBE/2020-04-09: (lb): Pretty sure we're missing code to
+            # reset the fact. (This code path used to be taken when a fact
+            # end time < its start time. But that case is now handled earlier,
+            # and the flow won't make it here. And if you set a fact's start
+            # time earlier than the previous fact start time, it'll be auto-
+            # corrected. So I'm not quite sure what use case triggers this
+            # branch anymore!)
+            self.affirm(edit_fact.start == was_fact.start)
+            self.affirm(edit_fact.end == was_fact.end)
+            # FIXME/2020-04-09: (lb): Seriously, what gets you here?
+            # - Document what use case gets you here if/when this fires.
+            self.affirm(False)
+            # Update the control text.
+            self.active_widgets.text_area.text = was_time
 
         def edited_fact_conflicts(edit_fact):
             # Skip all unstored, edited Facts.
